==> tine20-allinone_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sv_SE\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Uppgift"
 ,"Uppgifter"

]
, "Percent"
: "Procent"

, "Completed"
: "Avslutande"

, "Due"
: "För"

, "Class"
: ""

, "Description"
: "Beskrivning"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organiserare"

, "Priority"
: "Prioritet"

, "Status, Status"
: [
  "Status"
 ,"statusar"

]
, "Lead"
: "Lead"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Du måste ange ett förfallodatum, för ett alarm är ställt"

, "Summary"
: "Summa"

, "Due date"
: "Förfallo datum"

, "Add Responsible ..."
: "Lägg till Ansvarig ..."

, "Notes"
: "Noteringar"

, "Enter description..."
: "Ange beskrivning"

, "Percentage"
: "Procent"

, "Tasks"
: "Uppgifter"

, "to do list, to do lists"
: [
  "att göra lista"
 ,"att göra listor"

]
, "to do lists"
: "att göra listor"

, "Quick Search"
: ""

, "Due Date"
: "Förfallo datum"

, "Responsible"
: "Ansvarig"

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapande Tid"

, "Created By"
: "Skapad av"

, "New Task"
: "Ny Uppgift"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Vill du verkligen radera den valda uppgiften?"
 ,"Vill du verkligen radera dem valda uppgifterna?"

]
, "Attachments"
: ""

, "Tags"
: "Taggar"

, "Lead name"
: ""

, "Add a task..."
: "Lägg till en uppgift..."

, "All my tasks"
: "Alla mina uppgifter"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on Tasks startup"
: "Standard favorit som är laddad på Uppgifts start"

, "Default Task List"
: "Standard Uppgift Lista"

, "The default task list to create new tasks in."
: "Standard uppgift lista för att skapa nya uppgifter i."

, "Tasks status available"
: "uppgifter status tillgänglig"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Möjlig uppgifter status. Observera att ytterligare deltagare status kan påverka andra uppgifter system på export eller synkronisering."

, "No response"
: "inget svar"

, "Cancelled"
: "Avbruten"

, "In process"
: "I process"

, "Task priorities available"
: "Uppgift prioriteringar tillgängligt"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Möjliga uppgift prioriteringar. Observera att ytterligare prioriteringar kan påverka andra uppgifter system på export eller synkronisering."

, "low"
: "låg"

, "normal"
: "normal"

, "high"
: "hög"

, "urgent"
: "viktig"

, "manage shared task lists"
: "hantera delade uppgifts listor"

, "Create new shared tasks lists"
: "Skapa nya delade uppgifts listor"

, "manage shared tasks favorites"
: "hantera delade uppgifter favoriter"

, "Create or update shared tasks favorites"
: "Skapa eller uppdatera delade uppgifter favoriter"

, "%s's personal tasks"
: "%s personliga uppgifter"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Alla uppgifter av min uppgiftslista"

, "My open tasks"
: "Mina öppna uppgifter"

, "My open tasks this week"
: "Mina öppna uppgifter denna vecka"

, "All tasks for me"
: "Alla uppgifter för mig"

, "All tasks that I am responsible for"
: "Alla uppgifter som Jag är ansvarig för"

, "Last modified by me"
: "Senast ändrad av mig"

, "All tasks that I have last modified"
: "Alla uppgifter som jag senast har ändrat"

, "Tasks without responsible"
: "Uppgifter utan ansvar"

, "GENDER_Task"
: ""

, "Task"
: "Uppgift"

, "Status"
: "Status"

, "to do list"
: "att göra lista"

, "Do you really want to delete the selected task?"
: "Vill du verkligen radera den valda uppgiften?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Du måste ange ett förfallodatum, för ett alarm är ställt"

, "Summary"
: "Summa"

, "Due date"
: "Förfallo datum"

, "Priority"
: "Prioritet"

, "Organizer"
: "Organiserare"

, "Add Responsible ..."
: "Lägg till Ansvarig ..."

, "Notes"
: "Noteringar"

, "Enter description..."
: "Ange beskrivning"

, "Percentage"
: "Procent"

, "Status, Status"
: [
  "Status"
 ,"statusar"

]
, "Completed"
: "Avslutande"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Vill du verkligen radera den valda uppgiften?"
 ,"Vill du verkligen radera dem valda uppgifterna?"

]
, "Attachments"
: ""

, "Tags"
: "Taggar"

, "Lead name"
: ""

, "Add a task..."
: "Lägg till en uppgift..."

, "Due Date"
: "Förfallo datum"

, "Percent"
: "Procent"

, "Responsible"
: "Ansvarig"

, "Task, Tasks"
: [
  "Uppgift"
 ,"Uppgifter"

]
, "Tasks"
: "Uppgifter"

, "to do list, to do lists"
: [
  "att göra lista"
 ,"att göra listor"

]
, "to do lists"
: "att göra listor"

, "Quick Search"
: ""

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapande Tid"

, "Created By"
: "Skapad av"

, "New Task"
: "Ny Uppgift"

, "All my tasks"
: "Alla mina uppgifter"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on Tasks startup"
: "Standard favorit som är laddad på Uppgifts start"

, "Default Task List"
: "Standard Uppgift Lista"

, "The default task list to create new tasks in."
: "Standard uppgift lista för att skapa nya uppgifter i."

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "uppgifter status tillgänglig"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Möjlig uppgifter status. Observera att ytterligare deltagare status kan påverka andra uppgifter system på export eller synkronisering."

, "No response"
: "inget svar"

, "Cancelled"
: "Avbruten"

, "In process"
: "I process"

, "Task priorities available"
: "Uppgift prioriteringar tillgängligt"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Möjliga uppgift prioriteringar. Observera att ytterligare prioriteringar kan påverka andra uppgifter system på export eller synkronisering."

, "low"
: "låg"

, "normal"
: "normal"

, "high"
: "hög"

, "urgent"
: "viktig"

, "%s's personal tasks"
: "%s personliga uppgifter"

, "GENDER_Task"
: ""

, "Due"
: "För"

, "Class"
: ""

, "Description"
: "Beskrivning"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Lead"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Alla uppgifter av min uppgiftslista"

, "My open tasks"
: "Mina öppna uppgifter"

, "My open tasks this week"
: "Mina öppna uppgifter denna vecka"

, "All tasks for me"
: "Alla uppgifter för mig"

, "All tasks that I am responsible for"
: "Alla uppgifter som Jag är ansvarig för"

, "Last modified by me"
: "Senast ändrad av mig"

, "All tasks that I have last modified"
: "Alla uppgifter som jag senast har ändrat"

, "Tasks without responsible"
: "Uppgifter utan ansvar"

, "manage shared task lists"
: "hantera delade uppgifts listor"

, "Create new shared tasks lists"
: "Skapa nya delade uppgifts listor"

, "manage shared tasks favorites"
: "hantera delade uppgifter favoriter"

, "Create or update shared tasks favorites"
: "Skapa eller uppdatera delade uppgifter favoriter"

, "Status"
: "Status"

, "Do you really want to delete the selected task?"
: "Vill du verkligen radera den valda uppgiften?"

, "Task"
: "Uppgift"

, "to do list"
: "att göra lista"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
